@@ -18,11 +18,7 @@ class DiskUsage(BaseHealthCheckBackend):
         try:
             du = psutil.disk_usage("/")
             if DISK_USAGE_MAX and du.percent >= DISK_USAGE_MAX:
-                raise ServiceWarning(
-                    "{host} {percent}% disk usage exceeds {disk_usage}%".format(
-                        host=host, percent=du.percent, disk_usage=DISK_USAGE_MAX
-                    )
-                )
+                raise ServiceWarning(f"{host} {du.percent}% disk usage exceeds {DISK_USAGE_MAX}%")
         except ValueError as e:
             self.add_error(ServiceReturnedUnexpectedResult("ValueError"), e)
 
@@ -33,12 +29,8 @@ class MemoryUsage(BaseHealthCheckBackend):
             memory = psutil.virtual_memory()
             if MEMORY_MIN and memory.available < (MEMORY_MIN * 1024 * 1024):
                 locale.setlocale(locale.LC_ALL, "")
-                avail = "{:n}".format(int(memory.available / 1024 / 1024))
-                threshold = "{:n}".format(MEMORY_MIN)
-                raise ServiceWarning(
-                    "{host} {avail} MB available RAM below {threshold} MB".format(
-                        host=host, avail=avail, threshold=threshold
-                    )
-                )
+                avail = f"{int(memory.available / 1024 / 1024):n}"
+                threshold = f"{MEMORY_MIN:n}"
+                raise ServiceWarning(f"{host} {avail} MB available RAM below {threshold} MB")
         except ValueError as e:
             self.add_error(ServiceReturnedUnexpectedResult("ValueError"), e)
