@@ -19,9 +19,7 @@ class RabbitMQHealthCheck(BaseHealthCheckBackend):
         """Check RabbitMQ service by opening and closing a broker channel."""
         logger.debug("Checking for a broker_url on django settings...")
 
-        broker_url_setting_key = (
-            f"{self.namespace}_BROKER_URL" if self.namespace else "BROKER_URL"
-        )
+        broker_url_setting_key = f"{self.namespace}_BROKER_URL" if self.namespace else "BROKER_URL"
         broker_url = getattr(settings, broker_url_setting_key, None)
 
         logger.debug("Got %s as the broker_url. Connecting to rabbit...", broker_url)
@@ -33,21 +31,17 @@ class RabbitMQHealthCheck(BaseHealthCheckBackend):
                 conn.connect()  # exceptions may be raised upon calling connect
         except ConnectionRefusedError as e:
             self.add_error(
-                ServiceUnavailable(
-                    "Unable to connect to RabbitMQ: Connection was refused."
-                ),
+                ServiceUnavailable("Unable to connect to RabbitMQ: Connection was refused."),
                 e,
             )
 
         except AccessRefused as e:
             self.add_error(
-                ServiceUnavailable(
-                    "Unable to connect to RabbitMQ: Authentication error."
-                ),
+                ServiceUnavailable("Unable to connect to RabbitMQ: Authentication error."),
                 e,
             )
 
-        except IOError as e:
+        except OSError as e:
             self.add_error(ServiceUnavailable("IOError"), e)
 
         except BaseException as e:
