@@ -1,13 +1,7 @@
 import uuid
 
-import django
 from django.core.files.base import ContentFile
-from django.core.files.storage import default_storage
-
-if django.VERSION >= (4, 2):
-    from django.core.files.storage import InvalidStorageError, storages
-else:
-    from django.core.files.storage import get_storage_class
+from django.core.files.storage import InvalidStorageError, default_storage, storages
 
 from health_check.backends import BaseHealthCheckBackend
 from health_check.exceptions import ServiceUnavailable
@@ -31,19 +25,13 @@ class StorageHealthCheck(BaseHealthCheckBackend):
     storage = None
 
     def get_storage(self):
-        if django.VERSION >= (4, 2):
-            try:
-                return storages[self.storage_alias]
-            except InvalidStorageError:
-                return None
-        else:
-            if isinstance(self.storage, str):
-                return get_storage_class(self.storage)()
-            else:
-                return self.storage
+        try:
+            return storages[self.storage_alias]
+        except InvalidStorageError:
+            return None
 
     def get_file_name(self):
-        return "health_check_storage_test/test-%s.txt" % uuid.uuid4()
+        return f"health_check_storage_test/test-{uuid.uuid4()}.txt"
 
     def get_file_content(self):
         return b"this is the healthtest file content"
@@ -75,6 +63,8 @@ class StorageHealthCheck(BaseHealthCheckBackend):
             file_name = self.check_save(file_name, file_content)
             self.check_delete(file_name)
             return True
+        except ServiceUnavailable as e:
+            raise e
         except Exception as e:
             raise ServiceUnavailable("Unknown exception") from e
 
