@@ -22,8 +22,9 @@ class CustomStorage(Storage):
 class MockStorage(Storage):
     """
     A Mock Storage backend used for testing.
+
     saves - Determines whether save will mock a successful or unsuccessful save
-    deletes -  Determines whether save will mock a successful or unsuccessful deletion
+    deletes -  Determines whether save will mock a successful or unsuccessful deletion.
     """
 
     MOCK_FILE_COUNT = 0
@@ -31,7 +32,7 @@ class MockStorage(Storage):
     deletes = None
 
     def __init__(self, saves=True, deletes=True):
-        super(MockStorage, self).__init__()
+        super().__init__()
         self.MOCK_FILE_COUNT = 0
         self.saves = saves
         self.deletes = deletes
@@ -50,9 +51,7 @@ class MockStorage(Storage):
 
 # Mocking the S3Boto3Storage backend
 class MockS3Boto3Storage:
-    """
-    A mock S3Boto3Storage backend to simulate interactions with AWS S3.
-    """
+    """S3Boto3Storage backend mock to simulate interactions with AWS S3."""
 
     def __init__(self, saves=True, deletes=True):
         self.saves = saves
@@ -61,7 +60,8 @@ class MockS3Boto3Storage:
 
     def open(self, name, mode="rb"):
         """
-        Simulates opening a file from the mocked S3 storage.
+        Simulate file opening from the mocked S3 storage.
+
         For simplicity, this doesn't differentiate between read and write modes.
         """
         if name in self.files:
@@ -76,7 +76,8 @@ class MockS3Boto3Storage:
 
     def save(self, name, content):
         """
-        Overriding save to ensure content is stored as bytes in a way compatible with open method.
+        Ensure content is stored as bytes in a way compatible with open method.
+
         Assumes content is either a ContentFile, bytes, or a string that needs conversion.
         """
         if self.saves:
@@ -112,9 +113,7 @@ def get_file_content(*args, **kwargs):
     return b"mockcontent"
 
 
-@mock.patch(
-    "health_check.storage.backends.StorageHealthCheck.get_file_name", get_file_name
-)
+@mock.patch("health_check.storage.backends.StorageHealthCheck.get_file_name", get_file_name)
 @mock.patch(
     "health_check.storage.backends.StorageHealthCheck.get_file_content",
     get_file_content,
@@ -122,6 +121,7 @@ def get_file_content(*args, **kwargs):
 class HealthCheckStorageTests(TestCase):
     """
     Tests health check behavior with a mocked storage backend.
+
     Ensures check_status returns/raises the expected result when the storage works or raises exceptions.
     """
 
@@ -143,12 +143,9 @@ class HealthCheckStorageTests(TestCase):
             default_storage = DefaultFileStorageHealthCheck()
             self.assertIsInstance(default_storage.get_storage(), CustomStorage)
 
-    @unittest.skipUnless((4, 2) <= django.VERSION, "Django 4.2+ required")
     def test_get_storage_django_42_plus(self):
         """Check that the new STORAGES setting is supported."""
-        with self.settings(
-            STORAGES={"default": {"BACKEND": "tests.test_storage.CustomStorage"}}
-        ):
+        with self.settings(STORAGES={"default": {"BACKEND": "tests.test_storage.CustomStorage"}}):
             default_storage = DefaultFileStorageHealthCheck()
             self.assertIsInstance(default_storage.get_storage(), CustomStorage)
 
@@ -162,9 +159,7 @@ class HealthCheckStorageTests(TestCase):
 
         default_storage = default_storage_health.get_storage()
 
-        default_storage_open = "{}.{}.open".format(
-            default_storage.__module__, default_storage.__class__.__name__
-        )
+        default_storage_open = f"{default_storage.__module__}.{default_storage.__class__.__name__}.open"
 
         with mock.patch(
             default_storage_open,
@@ -172,45 +167,21 @@ class HealthCheckStorageTests(TestCase):
         ):
             self.assertTrue(default_storage_health.check_status())
 
-    @unittest.skipUnless(django.VERSION <= (4, 1), "Only for Django 4.1 and earlier")
-    @mock.patch(
-        "health_check.storage.backends.DefaultFileStorageHealthCheck.storage",
-        MockStorage(saves=False),
-    )
-    def test_file_does_not_exist_django_41_earlier(self):
-        """Test check_status raises ServiceUnavailable when file is not saved."""
-        default_storage_health = DefaultFileStorageHealthCheck()
-        with self.assertRaises(ServiceUnavailable):
-            default_storage_health.check_status()
-
-    @unittest.skipUnless((4, 2) <= django.VERSION, "Only for Django 4.2+")
     @mock.patch(
         "health_check.storage.backends.storages",
         {"default": MockStorage(saves=False)},
     )
-    def test_file_does_not_exist_django_42_plus(self):
+    def test_file_does_not_exist(self):
         """Test check_status raises ServiceUnavailable when file is not saved."""
         default_storage_health = DefaultFileStorageHealthCheck()
         with self.assertRaises(ServiceUnavailable):
             default_storage_health.check_status()
 
-    @unittest.skipUnless(django.VERSION <= (4, 1), "Only for Django 4.1 and earlier")
-    @mock.patch(
-        "health_check.storage.backends.DefaultFileStorageHealthCheck.storage",
-        MockStorage(deletes=False),
-    )
-    def test_file_not_deleted_django_41_earlier(self):
-        """Test check_status raises ServiceUnavailable when file is not deleted."""
-        default_storage_health = DefaultFileStorageHealthCheck()
-        with self.assertRaises(ServiceUnavailable):
-            default_storage_health.check_status()
-
-    @unittest.skipUnless((4, 2) <= django.VERSION, "Only for Django 4.2+")
     @mock.patch(
         "health_check.storage.backends.storages",
         {"default": MockStorage(deletes=False)},
     )
-    def test_file_not_deleted_django_42_plus(self):
+    def test_file_not_deleted(self):
         """Test check_status raises ServiceUnavailable when file is not deleted."""
         default_storage_health = DefaultFileStorageHealthCheck()
         with self.assertRaises(ServiceUnavailable):
@@ -224,27 +195,8 @@ class HealthCheckStorageTests(TestCase):
     }
 )
 class HealthCheckS3Boto3StorageTests(TestCase):
-    """
-    Tests health check behavior with a mocked S3Boto3Storage backend.
-    """
+    """Tests health check behavior with a mocked S3Boto3Storage backend."""
 
-    @unittest.skipUnless(django.VERSION <= (4, 1), "Only for Django 4.1 and earlier")
-    @mock.patch(
-        "storages.backends.s3boto3.S3Boto3Storage",
-        MockS3Boto3Storage(deletes=False),
-    )
-    def test_check_delete_success_django_41_earlier(self):
-        """Test that check_delete correctly deletes a file when S3Boto3Storage is working."""
-        health_check = S3Boto3StorageHealthCheck()
-        mock_storage = health_check.get_storage()
-        file_name = "testfile.txt"
-        content = BytesIO(b"Test content")
-        mock_storage.save(file_name, content)
-
-        with self.assertRaises(ServiceUnavailable):
-            health_check.check_delete(file_name)
-
-    @unittest.skipUnless((4, 2) <= django.VERSION, "Only for Django 4.2+")
     def test_check_delete_success(self):
         """Test that check_delete correctly deletes a file when S3Boto3Storage is working."""
         health_check = S3Boto3StorageHealthCheck()
@@ -267,18 +219,6 @@ class HealthCheckS3Boto3StorageTests(TestCase):
             with self.assertRaises(ServiceUnavailable):
                 health_check.check_delete("testfile.txt")
 
-    @unittest.skipUnless(django.VERSION <= (4, 1), "Only for Django 4.1 and earlier")
-    @mock.patch(
-        "storages.backends.s3boto3.S3Boto3Storage",
-        MockS3Boto3Storage(deletes=False),
-    )
-    def test_check_status_working_django_41_earlier(self):
-        """Test check_status returns True when S3Boto3Storage can save and delete files."""
-        health_check = S3Boto3StorageHealthCheck()
-        with self.assertRaises(ServiceUnavailable):
-            self.assertTrue(health_check.check_status())
-
-    @unittest.skipUnless((4, 2) <= django.VERSION, "Only for Django 4.2+")
     def test_check_status_working(self):
         """Test check_status returns True when S3Boto3Storage can save and delete files."""
         health_check = S3Boto3StorageHealthCheck()
@@ -286,18 +226,14 @@ class HealthCheckS3Boto3StorageTests(TestCase):
 
     def test_check_status_failure_on_save(self):
         """Test check_status raises ServiceUnavailable when file cannot be saved."""
-        with mock.patch.object(
-            MockS3Boto3Storage, "save", side_effect=Exception("Failed to save file.")
-        ):
+        with mock.patch.object(MockS3Boto3Storage, "save", side_effect=Exception("Failed to save file.")):
             health_check = S3Boto3StorageHealthCheck()
             with self.assertRaises(ServiceUnavailable):
                 health_check.check_status()
 
     def test_check_status_failure_on_delete(self):
         """Test check_status raises ServiceUnavailable when file cannot be deleted."""
-        with mock.patch.object(
-            MockS3Boto3Storage, "exists", new_callable=mock.PropertyMock
-        ) as mock_exists:
+        with mock.patch.object(MockS3Boto3Storage, "exists", new_callable=mock.PropertyMock) as mock_exists:
             mock_exists.return_value = False
             health_check = S3Boto3StorageHealthCheck()
             with self.assertRaises(ServiceUnavailable):
