@@ -30,6 +30,8 @@ INSTALLED_APPS = (
     "health_check.contrib.migrations",
     "health_check.contrib.celery_ping",
     "health_check.contrib.s3boto_storage",
+    "health_check.contrib.db_heartbeat",
+    "health_check.contrib.mail",
     "tests",
 )
 
